package com.ruoyi.invest.service;

import java.util.List;
import com.ruoyi.invest.domain.FutureStocksBill;
import com.ruoyi.invest.domain.dto.FutureStocksBillDto;
import com.ruoyi.invest.domain.vo.FutureStocksBillVo;

/**
 * 期货股票账单Service接口
 *
 * @author tianyongbao
 * @date 2024-03-20
 */
public interface IFutureStocksBillService
{
    /**
     * 查询期货股票账单
     *
     * @param id 期货股票账单主键
     * @return 期货股票账单
     */
    public FutureStocksBillVo selectFutureStocksBillById(Long id);

    /**
     * 查询期货股票账单列表
     *
     * @param futureStocksBillDto 期货股票账单
     * @return 期货股票账单集合
     */
    public List<FutureStocksBillVo> selectFutureStocksBillList(FutureStocksBillDto futureStocksBillDto);

    /**
     * 新增期货股票账单
     *
     * @param futureStocksBill 期货股票账单
     * @return 结果
     */
    public int insertFutureStocksBill(FutureStocksBill futureStocksBill);

    /**
     * 修改期货股票账单
     *
     * @param futureStocksBill 期货股票账单
     * @return 结果
     */
    public int updateFutureStocksBill(FutureStocksBill futureStocksBill);

    /**
     * 批量删除期货股票账单
     *
     * @param ids 需要删除的期货股票账单主键集合
     * @return 结果
     */
    public int deleteFutureStocksBillByIds(Long[] ids);

    /**
     * 删除期货股票账单信息
     *
     * @param id 期货股票账单主键
     * @return 结果
     */
    public int deleteFutureStocksBillById(Long id);
}
