package com.ruoyi.invest.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.invest.domain.FutureStocksBill;
import com.ruoyi.invest.domain.vo.FutureStocksBillVo;
import com.ruoyi.invest.domain.dto.FutureStocksBillDto;
import com.ruoyi.invest.service.IFutureStocksBillService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 期货股票账单Controller
 *
 * @author tianyongbao
 * @date 2024-03-20
 */
@Api(tags=" 期货股票账单")
@RestController
@RequestMapping("/futureStocksBill")
public class FutureStocksBillController extends BaseController
{
    @Resource
    private IFutureStocksBillService futureStocksBillService;

    /**
     * 查询期货股票账单列表
     */
    @ApiOperation(value="查询期货股票账单列表",response = FutureStocksBillVo.class)
    @RequiresPermissions("invest:futureStocksBill:list")
    @GetMapping("/list")
    public TableDataInfo list(FutureStocksBillDto futureStocksBillDto)
    {
        startPage();
        List<FutureStocksBillVo> list = futureStocksBillService.selectFutureStocksBillList(futureStocksBillDto);
        return getDataTable(list);
    }

    /**
     * 导出期货股票账单列表
     */
    @ApiOperation(value="导出期货股票账单列表")
    @RequiresPermissions("invest:futureStocksBill:export")
    @Log(title = "期货股票账单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FutureStocksBillDto futureStocksBillDto)
    {
        List<FutureStocksBillVo> list = futureStocksBillService.selectFutureStocksBillList(futureStocksBillDto);
        ExcelUtil<FutureStocksBillVo> util = new ExcelUtil<FutureStocksBillVo>(FutureStocksBillVo.class);
        util.exportExcel(response, list, "期货股票账单数据");
    }

    /**
     * 获取期货股票账单详细信息
     */
    @ApiOperation(value="获取期货股票账单详细信息")
    @RequiresPermissions("invest:futureStocksBill:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(futureStocksBillService.selectFutureStocksBillById(id));
    }

    /**
     * 新增期货股票账单
     */
    @ApiOperation(value="新增期货股票账单")
    @RequiresPermissions("invest:futureStocksBill:add")
    @Log(title = "期货股票账单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FutureStocksBill futureStocksBill)
    {
        return toAjax(futureStocksBillService.insertFutureStocksBill(futureStocksBill));
    }

    /**
     * 修改期货股票账单
     */
    @ApiOperation(value="修改期货股票账单")
    @RequiresPermissions("invest:futureStocksBill:edit")
    @Log(title = "期货股票账单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FutureStocksBill futureStocksBill)
    {
        return toAjax(futureStocksBillService.updateFutureStocksBill(futureStocksBill));
    }

    /**
     * 删除期货股票账单
     */
    @ApiOperation(value="删除期货股票账单")
    @RequiresPermissions("invest:futureStocksBill:remove")
    @Log(title = "期货股票账单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(futureStocksBillService.deleteFutureStocksBillByIds(ids));
    }
}
